@@ -1,4 +1,4 @@
-"""Main module fo yamlbase"""
+"""Main module fo YamlBase"""
 
 from .ybase import YBase
 from .exceptions import ActionNotFound, DataBaseTypeNotFound, ActionConfigSyntaxError, FieldNotFoundError, \
