@@ -23,7 +23,7 @@ class Column:
     def __str__(self):
 
         return f"column_name = {self.column_name}\ncolumn_type = {self.column_type}\n" \
-               f"is_pk = {self.is_pk}\nsk_link = {self.sk_link}"
+               f"is_pk = {self.is_pk}\nis_sk = {self.is_sk}\nsk_link = {self.sk_link}"
 
 
 @dataclass
@@ -36,4 +36,4 @@ class Table:
 
     def __eq__(self, other):
         return self.table_name == other.table_name and self.schema_name == other.schema_name and \
-               self.columns == other.columns
+               all([i in other.columns for i in self.columns])
