@@ -1,4 +1,4 @@
-"""Main file of yamlbase"""
+"""Main file of YamlBase"""
 
 import argparse
 import yaml
