@@ -1,20 +1,21 @@
-"""Main module file of yamlbase"""
+"""Main module file of YamlBase"""
 
 from YamlBase.dbworkers import SQLiteWorker
+from YamlBase.table_representation import Table
 from YamlBase.yaml_worker import YamlDataBaseWorker, YamlActionsWorker
 from YamlBase.exceptions import InsertActionImpossibleError, DataBaseTypeNotFound, ActionNotFound, \
     RemoveActionImpossibleError
 
 
 class YBase:
-    """Main class of yamlbase"""
-    def __init__(self, path_to_yaml_db, path_to_yaml_actions):
+    """Main class of YamlBase"""
+    def __init__(self, path_to_yaml_db):
         """
         :param path_to_yaml_db: path to yaml representation of DataBase
-        :param path_to_yaml_actions: path to yaml with actions config
         """
         self.yaml_config = YamlDataBaseWorker(path_to_yaml_db)
-        self.actions_config = YamlActionsWorker(path_to_yaml_actions)
+        folder_path = '/'.join(path_to_yaml_db.split('/')[:-1]) + '/'
+        self.actions_config = YamlActionsWorker(folder_path+self.yaml_config.db_info['db_name'])
         self.db_worker = self.initialize_worker()
 
     def initialize_worker(self):
@@ -26,12 +27,12 @@ class YBase:
     def do_actions(self):
         for table, action in self.actions_config.action_table.items():
             try:
-                self.do_action(action, self._filter_table(table))
+                self.do_action(action, self._filter_table_by_tablename(table))
                 print(f"\nSUCCESS ACTION {action} on table {table}\n")
             except Exception as e:
                 print(f"\nFAILED ACTION {action} on table {table}\nReason: {e}\n")
 
-    def _filter_table(self, table_name):
+    def _filter_table_by_tablename(self, table_name):
         return [i for i in self.yaml_config.tables_info if i.table_name == table_name][0]
 
     def do_action(self, action, table_name):
@@ -47,7 +48,7 @@ class YBase:
 
         raise ActionNotFound(action)
 
-    def check_action_possibility(self, action, table_obj):
+    def check_action_possibility(self, action: str, table_obj: Table):
         action_is_possible = True
         if action == 'insert':
             if not self.db_worker.check_insert_table_possibility(table_obj.table_name):
@@ -63,14 +64,14 @@ class YBase:
                     return action_is_possible
         return action_is_possible
 
-    def insert_action(self, new_table_name):
-        if not self.check_action_possibility('insert', new_table_name):
+    def insert_action(self, new_table: Table):
+        if not self.check_action_possibility('insert', new_table):
             raise InsertActionImpossibleError()
 
-        self.db_worker.insert_new_table(new_table_name)
+        self.db_worker.insert_new_table(new_table)
 
-    def remove_action(self, remove_table_name):
-        if not self.check_action_possibility('remove', remove_table_name):
+    def remove_action(self, remove_table: Table):
+        if not self.check_action_possibility('remove', remove_table):
             raise RemoveActionImpossibleError()
 
-        self.db_worker.remove_table(remove_table_name)
+        self.db_worker.remove_table(remove_table)
