@@ -9,7 +9,7 @@ import pytest
 class TestSQLiteworker:
 
     def setup(self):
-        self.cfg = YamlDataBaseWorker("../test/test_base.yml")
+        self.cfg = YamlDataBaseWorker("./test/test_base.yml")
         self.sqlite_connector = SQLiteWorker(self.cfg)
 
     def test_remove_tables(self):
